;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "overleaf" "20250728.2103"
  "Sync and track changes live with overleaf."
  '((emacs     "29.4")
    (plz       "0.9")
    (websocket "1.15")
    (webdriver "0.1")
    (posframe  "1.4.4"))
  :url "https://github.com/vale981/overleaf.el"
  :commit "515e45df1bec11e1c0cd2dc4810c48f8ad0685cb"
  :revdesc "515e45df1bec"
  :keywords '("hypermedia" "tex" "comm")
  :maintainers '(("Valentin Boettcher" . "overleafatprotagon.space")))
